@@ -19,6 +19,7 @@ OC.L10N.register(
     "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bestillingen din",
     "Confirm" : "Bekreft",
     "This confirmation link expires in %s hours." : "Denne bekreftelseslinken utgår om %stimer.",
+    "Dear %s, your booking has been accepted." : "Kjære%s, bestillingen din har blitt akseptert.",
     "Date:" : "Dato:",
     "Where:" : "Hvor:",
     "Calendar" : "Kalender",
@@ -43,52 +44,12 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
     "Add new" : "Legg til ny",
     "Untitled calendar" : "Kalender uten tittel",
-    "Edit name" : "Rediger navn",
-    "Saving name …" : "Lagrer navn ...",
-    "Edit color" : "Rediger farge",
-    "Saving color …" : "Lagrer farge  ...",
-    "Copy private link" : "Kopier privat lenke",
-    "Export" : "Eksporter",
-    "Unshare from me" : "Fjern deling fra meg",
     "Disable calendar \"{calendar}\"" : "Deaktiver kalender \"{calendar}\"",
     "Disable untitled calendar" : "Deaktiver kalender uten tittel",
     "Enable untitled calendar" : "Aktiver kalender uten tittel",
     "An error occurred, unable to change visibility of the calendar." : "En feil oppstod, kan ikke endre synlighet til kalenderen.",
-    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
-    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
-    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
-    "An error occurred, unable to rename the calendar." : "Det oppstod en feil, klarte ikke å endre navn på kalenderen.",
-    "An error occurred, unable to change the calendar's color." : "En feil oppstod, kunne ikke endre fargen til kalenderen.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling av kalenderen om {countdown} sekund","Fjerner deling av kalenderen om {countdown} sekunder"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
-    "Share link" : "Del lenke",
-    "Publish calendar" : "Publiser kalender",
-    "Publishing calendar" : "Publiserer kalender",
-    "Copy public link" : "Kopier offentlig lenke",
-    "Send link to calendar via email" : "Sende lenke til kalenderen via e-post",
-    "Enter one address" : "Tast inn en adresse",
-    "Sending email …" : "Sender epost ...",
-    "Copy subscription link" : "Kopier abonnementslenke",
-    "Copying link …" : "Kopierer lenke ...",
-    "Copied link" : "Kopier lenke",
-    "Could not copy link" : "Klarte ikke å kopiere lenken",
-    "Copy embedding code" : "Kopier innbyggingskode",
-    "Copying code …" : "Kopierer kode ...",
-    "Copied code" : "Kode kopiert",
-    "Could not copy code" : "Klarte ikke å kopiere koden",
-    "Delete share link" : "Slett delingslenke",
-    "Deleting share link …" : "Sletter delingslenke ...",
-    "An error occurred, unable to publish calendar." : "Det oppstod en feil, klarte ikke å publisere kalenderen.",
-    "An error occurred, unable to send email." : "En feil oppstod, kan ikke sende e-post.",
-    "Embed code copied to clipboard." : "Innbyggingskode kopiert til utklippstavle.",
-    "Embed code could not be copied to clipboard." : "Innbyggingskode ble ikke kopiert til utklippstavle.",
-    "Unpublishing calendar failed" : "Fjerne publiseringen av kalenderen feilet.",
-    "Share with users or groups" : "Del med brukere eller grupper",
-    "No users or groups" : "Ingen brukere eller grupper",
-    "can edit" : "kan endre",
-    "Unshare with {displayName}" : "Fjern deling med {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "En feil oppstod, kan ikke endre fjerning av deling av kalenderen.",
-    "An error occurred, unable to change the permission of the share." : "En feil oppstod, kan ikke endre rettighetene til delingen.",
     "New calendar" : "Ny kalender",
     "Name for new calendar" : "Navn på ny kalender",
     "Creating calendar …" : "Oppretter kalender ...",
@@ -97,6 +58,13 @@ OC.L10N.register(
     "Creating subscription …" : "Oppretter abonnement ...",
     "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
+    "Copy subscription link" : "Kopier abonnementslenke",
+    "Copying link …" : "Kopierer lenke ...",
+    "Copied link" : "Kopier lenke",
+    "Could not copy link" : "Klarte ikke å kopiere lenken",
+    "Export" : "Eksporter",
+    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
+    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
     "Trash bin" : "Papirkurv",
     "Name" : "Navn",
     "Deleted" : "Slettet",
@@ -108,6 +76,30 @@ OC.L10N.register(
     "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
     "Do you really want to empty the trash bin?" : "Vil du virkelig tømme papirkurven?",
     "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendere.",
+    "Share link" : "Del lenke",
+    "Copy public link" : "Kopier offentlig lenke",
+    "Send link to calendar via email" : "Sende lenke til kalenderen via e-post",
+    "Enter one address" : "Tast inn en adresse",
+    "Sending email …" : "Sender epost ...",
+    "Copy embedding code" : "Kopier innbyggingskode",
+    "Copying code …" : "Kopierer kode ...",
+    "Copied code" : "Kode kopiert",
+    "Could not copy code" : "Klarte ikke å kopiere koden",
+    "Delete share link" : "Slett delingslenke",
+    "Deleting share link …" : "Sletter delingslenke ...",
+    "An error occurred, unable to publish calendar." : "Det oppstod en feil, klarte ikke å publisere kalenderen.",
+    "An error occurred, unable to send email." : "En feil oppstod, kan ikke sende e-post.",
+    "Embed code copied to clipboard." : "Innbyggingskode kopiert til utklippstavle.",
+    "Embed code could not be copied to clipboard." : "Innbyggingskode ble ikke kopiert til utklippstavle.",
+    "Unpublishing calendar failed" : "Fjerne publiseringen av kalenderen feilet.",
+    "can edit" : "kan endre",
+    "Unshare with {displayName}" : "Fjern deling med {displayName}",
+    "An error occurred, unable to change the unshare the calendar." : "En feil oppstod, kan ikke endre fjerning av deling av kalenderen.",
+    "An error occurred, unable to change the permission of the share." : "En feil oppstod, kan ikke endre rettighetene til delingen.",
+    "Share with users or groups" : "Del med brukere eller grupper",
+    "No users or groups" : "Ingen brukere eller grupper",
+    "Copy private link" : "Kopier privat lenke",
+    "Unshare from me" : "Fjern deling fra meg",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
     "Filename" : "Filnavn",
@@ -364,6 +356,7 @@ OC.L10N.register(
     "Add this as a new category" : "Legg til som ny kategori",
     "Custom color" : "Tilpasset farge",
     "Special color of this event. Overrides the calendar-color." : "Spesial farge for denne hendelsen. Overstyrer kalenderfargen.",
+    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
     "Imported {filename}" : "Importerte {filename}",
     "Meditation" : "Meditasjon",
     "Relaxing" : "Avslapping",
